pub struct DiffParams {
pub app: u32,
pub depot: u32,
pub from: u64,
pub to: u64,
pub branch: Option<String>,
pub format: Option<OutputFormat>,
}Fields
app: u32depot: u32from: u64to: u64branch: Option<String>format: Option<OutputFormat>Trait Implementations
Sourceimpl Archive for DiffParams
impl Archive for DiffParams
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDiffParams
type Archived = ArchivedDiffParams
The archived representation of this type. Read more
Sourcetype Resolver = DiffParamsResolver
type Resolver = DiffParamsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for DiffParams
impl Clone for DiffParams
Sourcefn clone(&self) -> DiffParams
fn clone(&self) -> DiffParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiffParams
impl Debug for DiffParams
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DiffParams, __D> for Archived<DiffParams>where
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<DiffParams, __D> for Archived<DiffParams>where
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DiffParams, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DiffParams, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl From<DiffArgs> for DiffParams
impl From<DiffArgs> for DiffParams
Sourceimpl From<DiffParams> for DiffArgs
impl From<DiffParams> for DiffArgs
Sourcefn from(p: DiffParams) -> Self
fn from(p: DiffParams) -> Self
Converts to this type from the input type.