pub struct DownloadParams {Show 22 fields
pub app: u32,
pub depot: Option<u32>,
pub manifest: Option<u64>,
pub filelist: Option<String>,
pub file_regex: Option<String>,
pub output: Option<String>,
pub verify: bool,
pub os: Option<String>,
pub arch: Option<String>,
pub language: Option<String>,
pub login_id: Option<u32>,
pub all_platforms: bool,
pub all_architectures: bool,
pub all_languages: bool,
pub lancache: bool,
pub max_downloads: Option<u32>,
pub branch: Option<String>,
pub branch_password: Option<String>,
pub local_keys: bool,
pub non_atomic: bool,
pub save_manifests: bool,
pub bytes: bool,
}Fields
app: u32depot: Option<u32>manifest: Option<u64>filelist: Option<String>file_regex: Option<String>output: Option<String>verify: boolos: Option<String>arch: Option<String>language: Option<String>login_id: Option<u32>all_platforms: boolall_architectures: boolall_languages: boollancache: boolmax_downloads: Option<u32>branch: Option<String>branch_password: Option<String>local_keys: boolnon_atomic: boolsave_manifests: boolbytes: boolTrait Implementations
Sourceimpl Archive for DownloadParams
impl Archive for DownloadParams
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDownloadParams
type Archived = ArchivedDownloadParams
The archived representation of this type. Read more
Sourcetype Resolver = DownloadParamsResolver
type Resolver = DownloadParamsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for DownloadParams
impl Clone for DownloadParams
Sourcefn clone(&self) -> DownloadParams
fn clone(&self) -> DownloadParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DownloadParams
impl Debug for DownloadParams
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DownloadParams, __D> for Archived<DownloadParams>where
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
impl<__D: Fallible + ?Sized> Deserialize<DownloadParams, __D> for Archived<DownloadParams>where
u32: Archive,
<u32 as Archive>::Archived: Deserialize<u32, __D>,
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DownloadParams, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DownloadParams, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl From<DownloadArgs> for DownloadParams
impl From<DownloadArgs> for DownloadParams
Sourcefn from(a: DownloadArgs) -> Self
fn from(a: DownloadArgs) -> Self
Converts to this type from the input type.
Sourceimpl From<DownloadParams> for DownloadArgs
impl From<DownloadParams> for DownloadArgs
Sourcefn from(p: DownloadParams) -> Self
fn from(p: DownloadParams) -> Self
Converts to this type from the input type.