pub struct FilesParams {
pub app: Option<u32>,
pub depot: Option<u32>,
pub manifest: Option<u64>,
pub manifest_file: Option<String>,
pub depot_key: Option<String>,
pub branch: Option<String>,
pub branch_password: Option<String>,
pub os: Option<String>,
pub format: Option<OutputFormat>,
pub raw: bool,
pub bytes: bool,
}Fields
app: Option<u32>depot: Option<u32>manifest: Option<u64>manifest_file: Option<String>depot_key: Option<String>branch: Option<String>branch_password: Option<String>os: Option<String>format: Option<OutputFormat>raw: boolbytes: boolTrait Implementations
Sourceimpl Archive for FilesParams
impl Archive for FilesParams
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFilesParams
type Archived = ArchivedFilesParams
The archived representation of this type. Read more
Sourcetype Resolver = FilesParamsResolver
type Resolver = FilesParamsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for FilesParams
impl Clone for FilesParams
Sourcefn clone(&self) -> FilesParams
fn clone(&self) -> FilesParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FilesParams
impl Debug for FilesParams
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FilesParams, __D> for Archived<FilesParams>where
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
impl<__D: Fallible + ?Sized> Deserialize<FilesParams, __D> for Archived<FilesParams>where
Option<u32>: Archive,
<Option<u32> as Archive>::Archived: Deserialize<Option<u32>, __D>,
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FilesParams, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FilesParams, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl From<FilesArgs> for FilesParams
impl From<FilesArgs> for FilesParams
Sourceimpl From<FilesParams> for FilesArgs
impl From<FilesParams> for FilesArgs
Sourcefn from(p: FilesParams) -> Self
fn from(p: FilesParams) -> Self
Converts to this type from the input type.