pub struct JobId(pub u64);Expand description
Monotonically increasing identifier minted by the daemon. Stable for the daemon’s lifetime; zero is reserved as “not a job”.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Archive for JobId
impl Archive for JobId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedJobId
type Archived = ArchivedJobId
The archived representation of this type. Read more
Sourcetype Resolver = JobIdResolver
type Resolver = JobIdResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Copy for JobId
Sourceimpl<'de> Deserialize<'de> for JobId
impl<'de> Deserialize<'de> for JobId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for JobId
impl StructuralPartialEq for JobId