pub struct LocalInfoParams {
pub format: Option<OutputFormat>,
pub user: Option<String>,
pub users: bool,
}Fields
format: Option<OutputFormat>user: Option<String>users: boolTrait Implementations
Sourceimpl Archive for LocalInfoParams
impl Archive for LocalInfoParams
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedLocalInfoParams
type Archived = ArchivedLocalInfoParams
The archived representation of this type. Read more
Sourcetype Resolver = LocalInfoParamsResolver
type Resolver = LocalInfoParamsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for LocalInfoParams
impl Clone for LocalInfoParams
Sourcefn clone(&self) -> LocalInfoParams
fn clone(&self) -> LocalInfoParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalInfoParams
impl Debug for LocalInfoParams
Sourceimpl<__D: Fallible + ?Sized> Deserialize<LocalInfoParams, __D> for Archived<LocalInfoParams>where
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
impl<__D: Fallible + ?Sized> Deserialize<LocalInfoParams, __D> for Archived<LocalInfoParams>where
Option<OutputFormat>: Archive,
<Option<OutputFormat> as Archive>::Archived: Deserialize<Option<OutputFormat>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<LocalInfoParams, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<LocalInfoParams, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl From<LocalInfoArgs> for LocalInfoParams
impl From<LocalInfoArgs> for LocalInfoParams
Sourcefn from(a: LocalInfoArgs) -> Self
fn from(a: LocalInfoArgs) -> Self
Converts to this type from the input type.
Sourceimpl From<LocalInfoParams> for LocalInfoArgs
impl From<LocalInfoParams> for LocalInfoArgs
Sourcefn from(p: LocalInfoParams) -> Self
fn from(p: LocalInfoParams) -> Self
Converts to this type from the input type.