pub struct ProgressUpdate {
pub bytes_done: u64,
pub bytes_total: u64,
pub files_done: u32,
pub files_total: u32,
pub rate_bytes_per_sec: u64,
pub eta_seconds: u32,
}Expand description
Per-job progress snapshot, emitted by the worker as Event::Progress.
Fields
bytes_done: u64bytes_total: u64files_done: u32files_total: u32rate_bytes_per_sec: u64eta_seconds: u32Trait Implementations
Sourceimpl Archive for ProgressUpdate
impl Archive for ProgressUpdate
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedProgressUpdate
type Archived = ArchivedProgressUpdate
The archived representation of this type. Read more
Sourcetype Resolver = ProgressUpdateResolver
type Resolver = ProgressUpdateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ProgressUpdate
impl Clone for ProgressUpdate
Sourcefn clone(&self) -> ProgressUpdate
fn clone(&self) -> ProgressUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressUpdate
impl Debug for ProgressUpdate
Sourceimpl<'de> Deserialize<'de> for ProgressUpdate
impl<'de> Deserialize<'de> for ProgressUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ProgressUpdate, __D> for Archived<ProgressUpdate>
impl<__D: Fallible + ?Sized> Deserialize<ProgressUpdate, __D> for Archived<ProgressUpdate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ProgressUpdate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ProgressUpdate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Serialize for ProgressUpdate
impl Serialize for ProgressUpdate